#ifndef __DEVHOOK_H__
/****************************************************************************
	devhook SDK header file version 0.42c
****************************************************************************/

/* get devhook driver version code */
/* 0.42b == 0x00420002 */
/* 0.43  == 0x00430000 */
unsigned int dhGetVersion(void);

/****************************************************************************
	configration / setting
****************************************************************************/

/*************************************
	DEVHOOK_CONFIG.flags 
*************************************/

// flags value
#define DH_FLAG_FLASH_EMU    0x00000010

// UMD emulation
#define DH_FLAG_SFO_VER      0x00000004
#define DH_FLAG_NOUMD        0x00000002
#define DH_FLAG_ANYUMD       0x00000001

// for vshex
#define DH_FLAG_XMB_INFO     0x01000000

// for debug
#define DH_FLAG_UMD_MON      0x80000000
#define DH_FLAG_KPRINT_UART  0x40000000

#define DH_MAGIC ('D'|('H'<<8)|('0'<<16)|('4'<<24))

typedef struct devhook_config
{
  int magic;              // +000:magic 'DH03'
  int flags;              // +004:setup flags
  int cpu_Mhz;            // +008:cpu speed
  int bus_Mhz;            // +00c:bus speed
  char rsv[0x2c];         // +010:reserved
  unsigned int preload_addr;// +03C:prx preload address(0.42c-)
  char flash[0x40];       // +040:flash redirect path
  char umd_path[128];     // +080:UMD emulation path
  char reboot_path[128];  // +100:reboot path(removed)
}DEVHOOK_CONFIG;

/*************************************
	get current configration 
*************************************/
int dhGetConfig(DEVHOOK_CONFIG *cfg_data);

/*************************************
	set configration
*************************************/
int dhSetConfig(DEVHOOK_CONFIG *cfg_data);

/****************************************************************************
	UMD controll
****************************************************************************/

int dhUMDMount(const char *path);
int dhUMDUnmount(void);

/****************************************************************************
	UMD emulator plugin

note:
	plugin which can be added is 8 devices.
	device which was registed last is called first.
	wehen return Mount callback
	If Mount callback returns less than 0, next device are called.
	It is Unmounted until it is inserted when MemoryStick is pulled out.

	see umd_iso.c for template.
****************************************************************************/

// plugin interface
typedef struct devhook_umd_plugin
{
	const char *devname;
	int (*Mount)(const char *path);                        // unmount event callback
	int (*Unmount)(void);                                  // mount event callback
	int (*GetCapacity)(void);                              // get number of sectors
	int (*Read)(void *buf,int top_sector,int num_bytes);   // read request
}DH_UMD_PLUGIN;

/*************************************
	add UMD emulator plugin
*************************************/
int dhUMDAddDevice(const DH_UMD_PLUGIN *interface);

/*************************************
	delete UMD emulator plugin
*************************************/
int dhUMDDelDevice(const DH_UMD_PLUGIN *interface);

/****************************************************************************
	usualy file access
note:
	file access with auto open/reopen/retry and stack extend.
****************************************************************************/
typedef struct dh_fileio_struct
{
	const char *path;		// file path      : arg1 of sceIoOpen
	int flags;				// file flag mode : arg2 of sceIoOpen
	SceMode mode;			// file open mode : arg3 of sceIoOpen
//
	SceUID fd;				// file dsscripter number
	int retry_cnt;			// retry counter
	int retry_interval;		// sleep time if error retry
	int stack_size;			// number of extended stack size,0 is no extend stack
}DH_FILE;

/*************************************
read with auto open/retry
*************************************/
int dhReadFileRetry(DH_FILE *fp,SceOff pos,void *buf,int size);

/*************************************
write with auto open/retry
*************************************/
int dhWriteFileRetry(DH_FILE *fp,SceOff pos,void *buf,int size);

/*************************************
close 
*************************************/
int dhCloseFile(DH_FILE *fp);

/****************************************************************************
	CLOCK controll
****************************************************************************/
int dhCLKSet(int cpuclk,int busclk);

#endif
